<?php

namespace Bixo\Account\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Bixo\Account\Http\Requests\JournalDetailRequest;
use Bixo\Account\Interfaces\JournalDetailRepositoryInterface;
use Bixo\Account\Models\JournalDetail;
use Bixo\Account\Forms\JournalDetail as Form;

/**
 * APIController  class for journal_detail.
 */
class JournalDetailAPIController extends BaseController
{

    /**
     * Initialize journal_detail resource controller.
     *
     * @param type JournalDetailRepositoryInterface $journal_detail
     *
     * @return null
     */
    public function __construct(JournalDetailRepositoryInterface $journal_detail)
    {
        parent::__construct();
        $this->repository = $journal_detail;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Bixo\Account\Repositories\Criteria\JournalDetailResourceCriteria::class);
    }

    /**
     * Display a list of journal_detail.
     *
     * @return Response
     */
    public function index(JournalDetailRequest $request)
    {
        return $this->repository
            ->setPresenter(\Bixo\Account\Repositories\Presenter\JournalDetailPresenter::class)
            ->paginate();
    }

    /**
     * Display journal_detail.
     *
     * @param Request $request
     * @param Model   $journal_detail
     *
     * @return Response
     */
    public function show(JournalDetailRequest $request, JournalDetail $journal_detail)
    {
        return $journal_detail->setPresenter(\Bixo\Account\Repositories\Presenter\JournalDetailListPresenter::class);
        ;
    }

    /**
     * Create new journal_detail.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(JournalDetailRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('account::journal_detail.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('account/journal_detail/' . $journal_detail->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('account/journal_detail');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the journal_detail.
     *
     * @param Request $request
     * @param Model   $journal_detail
     *
     * @return Response
     */
    public function update(JournalDetailRequest $request, JournalDetail $journal_detail)
    {
        try {
            $data = $request->all();

            $journal_detail->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('account::journal_detail.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('account/journal_detail/' . $journal_detail->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('account/journal_detail/' . $journal_detail->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the journal_detail.
     *
     * @param Model   $journal_detail
     *
     * @return Response
     */
    public function destroy(JournalDetailRequest $request, JournalDetail $journal_detail)
    {
        try {
            $journal_detail->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('account::journal_detail.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('account/journal_detail/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('account/journal_detail/' . $journal_detail->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
