<?php

namespace Bixo\Account\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Bixo\Account\Http\Requests\LedgerRequest;
use Bixo\Account\Interfaces\LedgerRepositoryInterface;
use Bixo\Account\Models\Ledger;
use Bixo\Account\Forms\Ledger as Form;

/**
 * APIController  class for ledger.
 */
class LedgerAPIController extends BaseController
{

    /**
     * Initialize ledger resource controller.
     *
     * @param type LedgerRepositoryInterface $ledger
     *
     * @return null
     */
    public function __construct(LedgerRepositoryInterface $ledger)
    {
        parent::__construct();
        $this->repository = $ledger;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Bixo\Account\Repositories\Criteria\LedgerResourceCriteria::class);
    }

    /**
     * Display a list of ledger.
     *
     * @return Response
     */
    public function index(LedgerRequest $request)
    {
        return $this->repository
            ->setPresenter(\Bixo\Account\Repositories\Presenter\LedgerPresenter::class)
            ->paginate();
    }

    /**
     * Display ledger.
     *
     * @param Request $request
     * @param Model   $ledger
     *
     * @return Response
     */
    public function show(LedgerRequest $request, Ledger $ledger)
    {
        return $ledger->setPresenter(\Bixo\Account\Repositories\Presenter\LedgerListPresenter::class);
        ;
    }

    /**
     * Create new ledger.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(LedgerRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('account::ledger.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('account/ledger/' . $ledger->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('account/ledger');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the ledger.
     *
     * @param Request $request
     * @param Model   $ledger
     *
     * @return Response
     */
    public function update(LedgerRequest $request, Ledger $ledger)
    {
        try {
            $data = $request->all();

            $ledger->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('account::ledger.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('account/ledger/' . $ledger->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('account/ledger/' . $ledger->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the ledger.
     *
     * @param Model   $ledger
     *
     * @return Response
     */
    public function destroy(LedgerRequest $request, Ledger $ledger)
    {
        try {
            $ledger->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('account::ledger.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('account/ledger/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('account/ledger/' . $ledger->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
