<?php

namespace Bixo\Account\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Account\Models\JournalDetail;

class JournalDetailPolicy
{

    /**
     * Determine if the given user can view the journal_detail.
     *
     * @param UserPolicy $user
     * @param JournalDetail $journal_detail
     *
     * @return bool
     */
    public function view(UserPolicy $user, JournalDetail $journal_detail)
    {
        if ($user->canDo('account.journal_detail.view') && $user->isAdmin()) {
            return true;
        }

        return $journal_detail->user_id == user_id() && $journal_detail->user_type == user_type();
    }

    /**
     * Determine if the given user can create a journal_detail.
     *
     * @param UserPolicy $user
     * @param JournalDetail $journal_detail
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('account.journal_detail.create');
    }

    /**
     * Determine if the given user can update the given journal_detail.
     *
     * @param UserPolicy $user
     * @param JournalDetail $journal_detail
     *
     * @return bool
     */
    public function update(UserPolicy $user, JournalDetail $journal_detail)
    {
        if ($user->canDo('account.journal_detail.edit') && $user->isAdmin()) {
            return true;
        }

        return $journal_detail->user_id == user_id() && $journal_detail->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given journal_detail.
     *
     * @param UserPolicy $user
     * @param JournalDetail $journal_detail
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, JournalDetail $journal_detail)
    {
        return $journal_detail->user_id == user_id() && $journal_detail->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given journal_detail.
     *
     * @param UserPolicy $user
     * @param JournalDetail $journal_detail
     *
     * @return bool
     */
    public function verify(UserPolicy $user, JournalDetail $journal_detail)
    {
        if ($user->canDo('account.journal_detail.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given journal_detail.
     *
     * @param UserPolicy $user
     * @param JournalDetail $journal_detail
     *
     * @return bool
     */
    public function approve(UserPolicy $user, JournalDetail $journal_detail)
    {
        if ($user->canDo('account.journal_detail.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
