<?php

namespace Bixo\Account\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Account\Models\Journal;

class JournalPolicy
{

    /**
     * Determine if the given user can view the journal.
     *
     * @param UserPolicy $user
     * @param Journal $journal
     *
     * @return bool
     */
    public function view(UserPolicy $user, Journal $journal)
    {
        if ($user->canDo('account.journal.view') && $user->isAdmin()) {
            return true;
        }

        return $journal->user_id == user_id() && $journal->user_type == user_type();
    }

    /**
     * Determine if the given user can create a journal.
     *
     * @param UserPolicy $user
     * @param Journal $journal
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('account.journal.create');
    }

    /**
     * Determine if the given user can update the given journal.
     *
     * @param UserPolicy $user
     * @param Journal $journal
     *
     * @return bool
     */
    public function update(UserPolicy $user, Journal $journal)
    {
        if ($user->canDo('account.journal.edit') && $user->isAdmin()) {
            return true;
        }

        return $journal->user_id == user_id() && $journal->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given journal.
     *
     * @param UserPolicy $user
     * @param Journal $journal
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Journal $journal)
    {
        return $journal->user_id == user_id() && $journal->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given journal.
     *
     * @param UserPolicy $user
     * @param Journal $journal
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Journal $journal)
    {
        if ($user->canDo('account.journal.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given journal.
     *
     * @param UserPolicy $user
     * @param Journal $journal
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Journal $journal)
    {
        if ($user->canDo('account.journal.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
