<?php

namespace Bixo\Account\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Account\Models\Ledger;

class LedgerPolicy
{

    /**
     * Determine if the given user can view the ledger.
     *
     * @param UserPolicy $user
     * @param Ledger $ledger
     *
     * @return bool
     */
    public function view(UserPolicy $user, Ledger $ledger)
    {
        if ($user->canDo('account.ledger.view') && $user->isAdmin()) {
            return true;
        }

        return $ledger->user_id == user_id() && $ledger->user_type == user_type();
    }

    /**
     * Determine if the given user can create a ledger.
     *
     * @param UserPolicy $user
     * @param Ledger $ledger
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('account.ledger.create');
    }

    /**
     * Determine if the given user can update the given ledger.
     *
     * @param UserPolicy $user
     * @param Ledger $ledger
     *
     * @return bool
     */
    public function update(UserPolicy $user, Ledger $ledger)
    {
        if ($user->canDo('account.ledger.edit') && $user->isAdmin()) {
            return true;
        }

        return $ledger->user_id == user_id() && $ledger->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given ledger.
     *
     * @param UserPolicy $user
     * @param Ledger $ledger
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Ledger $ledger)
    {
        return $ledger->user_id == user_id() && $ledger->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given ledger.
     *
     * @param UserPolicy $user
     * @param Ledger $ledger
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Ledger $ledger)
    {
        if ($user->canDo('account.ledger.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given ledger.
     *
     * @param UserPolicy $user
     * @param Ledger $ledger
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Ledger $ledger)
    {
        if ($user->canDo('account.ledger.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
